#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class DocumentAttributeAudio(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~telectron.raw.base.DocumentAttribute`.

    Details:
        - Layer: ``129``
        - ID: ``0x9852f9c6``

    Parameters:
        duration: ``int`` ``32-bit``
        voice (optional): ``bool``
        title (optional): ``str``
        performer (optional): ``str``
        waveform (optional): ``bytes``
    """

    __slots__: List[str] = ["duration", "voice", "title", "performer", "waveform"]

    ID = 0x9852f9c6
    QUALNAME = "types.DocumentAttributeAudio"

    def __init__(self, *, duration: int, voice: Union[None, bool] = None, title: Union[None, str] = None, performer: Union[None, str] = None, waveform: Union[None, bytes] = None) -> None:
        self.duration = duration  # int
        self.voice = voice  # flags.10?true
        self.title = title  # flags.0?string
        self.performer = performer  # flags.1?string
        self.waveform = waveform  # flags.2?bytes

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "DocumentAttributeAudio":
        flags = Int.read(data)
        
        voice = True if flags & (1 << 10) else False
        duration = Int.read(data)
        
        title = String.read(data) if flags & (1 << 0) else None
        performer = String.read(data) if flags & (1 << 1) else None
        waveform = Bytes.read(data) if flags & (1 << 2) else None
        return DocumentAttributeAudio(duration=duration, voice=voice, title=title, performer=performer, waveform=waveform)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 10) if self.voice else 0
        flags |= (1 << 0) if self.title is not None else 0
        flags |= (1 << 1) if self.performer is not None else 0
        flags |= (1 << 2) if self.waveform is not None else 0
        data.write(Int(flags))
        
        data.write(Int(self.duration))
        
        if self.title is not None:
            data.write(String(self.title))
        
        if self.performer is not None:
            data.write(String(self.performer))
        
        if self.waveform is not None:
            data.write(Bytes(self.waveform))
        
        return data.getvalue()
